@@ -20,12 +20,13 @@ our @EXPORT_OK = qw(
                        format_shell_completion
                );
 
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 our $DATE = '2014-06-29'; # DATE
 
 our %SPEC;
 
 # all complete_* routines accept hash/named args, the other accept positional.
+# complete_* routines complete for a specific type and return array of strings.
 
 $SPEC{complete_array} = {
     v => 1.1,
@@ -193,9 +194,6 @@ sub complete_file {
     mimic_shell_dir_completion($w);
 }
 
-# TODO: complete_user (probably in a separate module)
-# TODO: complete_group (probably in a separate module)
-# TODO: complete_pid (probably in a separate module)
 # TODO: complete_filesystem (probably in a separate module)
 # TODO: complete_hostname (/etc/hosts, ~/ssh/.known_hosts, ...)
 # TODO: complete_package (deb, rpm, ...)
@@ -228,6 +226,11 @@ _
             req=>1,
             pos=>0,
         },
+        sep => {
+            schema => 'str*',
+            default => '/',
+            pos => 1,
+        },
     },
     result_naked => 1,
     result => {
@@ -235,9 +238,10 @@ _
     },
 };
 sub mimic_shell_dir_completion {
-    my $c = shift;
-    return $c unless @$c == 1 && $c->[0] =~ m!/\z!;
-    [$c->[0], "$c->[0] "];
+    my ($comp, $sep) = @_;
+    $sep = '/' unless defined($sep) && length($sep);
+    return $comp unless @$comp == 1 && $comp->[0] =~ m!\Q$sep\E\z!;
+    [$comp->[0], "$comp->[0] "];
 }
 
 $SPEC{break_cmdline_into_words} = {
@@ -438,7 +442,8 @@ added for hints on how to format the completion reply more
 correctly/appropriately to the shell. Known hints: `type` (string, can be
 `filename`, `env`, or others; this helps the routine picks the appropriate
 escaping), `is_path` (bool, if set to true then `mimic_shell_dir_completion`
-logic is applied).
+logic is applied), `path_sep` (string, character to separate path, defaults to
+`/`).
 
 _
     args_as => 'array',
@@ -470,7 +475,8 @@ sub format_shell_completion {
 
     $shcomp //= {};
     my $comp = $shcomp->{completion} // [];
-    $comp = mimic_shell_dir_completion($comp) if $shcomp->{is_path};
+    $comp = mimic_shell_dir_completion($comp, $shcomp->{path_sep})
+        if $shcomp->{is_path};
     my $type = $shcomp->{type} // '';
 
     my @lines;
@@ -480,7 +486,7 @@ sub format_shell_completion {
             # don't escape $
             $str =~ s!([^A-Za-z0-9,+._/\$-])!\\$1!g;
         } else {
-            $str =~ s!([^A-Za-z0-9,+._/-])!\\$1!g;
+            $str =~ s!([^A-Za-z0-9,+._/:-])!\\$1!g;
         }
         $str .= "\n";
         push @lines, $str;
@@ -503,7 +509,7 @@ Complete::Util - Shell completion routines
 
 =head1 VERSION
 
-This document describes version 0.10 of Complete::Util (from Perl distribution Complete-Util), released on 2014-06-29.
+This document describes version 0.11 of Complete::Util (from Perl distribution Complete-Util), released on 2014-06-29.
 
 =head1 DESCRIPTION
 
@@ -692,7 +698,8 @@ added for hints on how to format the completion reply more
 correctly/appropriately to the shell. Known hints: C<type> (string, can be
 C<filename>, C<env>, or others; this helps the routine picks the appropriate
 escaping), C<is_path> (bool, if set to true then C<mimic_shell_dir_completion>
-logic is applied).
+logic is applied), C<path_sep> (string, character to separate path, defaults to
+C</>).
 
 Arguments ('*' denotes required arguments):
 
@@ -739,6 +746,8 @@ Arguments ('*' denotes required arguments):
 
 =item * B<completion>* => I<array>
 
+=item * B<sep> => I<str> (default: "/")
+
 =back
 
 Return value:
